/*    PEN.H    Header file for barcode decoder   */



#include <limits.h>             /* limits of numbers in environment */

/**** CODE 39 related definitions follow ****/


#define     MAX_CHARS     (34)  /* 32 characters + 2 st/sp */
/* Maximum number of characters in barcode including St/Sp/Ct codes:    */


#define     N             (2)    /* Wide is 2x nominal size */
/* Typical  Wide-to-Narrow ratio - decoder should usually be independet */
/* of the chose value:                                                  */


#define     X             (50)  /* Nominal element size is 50 counts    */
/* Nominal element size is the size of the 'narrow' element in the      */
/* barcode.   The reader should not depend on the harcoded X, but       */
/* rather on a dynamically computed X.  It is here for prototyping      */
/* use only.                                                            */


#define     QZ            (X*10) /* Minimum quiet zone required by AIM  */
/* The QZ, or quiet-zone value determine the number of apertures of     */
/* white bars that represent the presence of a quiet zone               */


#define     NOISE_MARGIN  (2)   /* up to 2 drops and voids per char     */
/* This value is used to determine the number of drops/voids per        */
/* character of code (on the average) that is allowable.   With the     */
/* use of the noise margins, ELEMENTS (below) can be allocated for      */
/* the appropriate number of elements including false elements read     */
/* due to drop/voids                                                    */


#define     MAX_BARS      ((10+NOISE_MARGIN)*MAX_CHARS)
/* This is the number of bars, maximum, that the system should expect   */
/* for any given decode run.  The value reflects 10 bars per character  */
/* (9 active, 1 separator), plus an over-head for noise                 */




#define UBYTE_8 unsigned char   /* unsigned 8-bit integer on PC's */
/* This defines what an unsigned 8-bit number on the system is */

#define UBYTE_MAX  UCHAR_MAX    /* Maximum size that UBYTE_8 can represent */


#define UWORD_16 unsigned int   /* unsigned 16-bit integer on PC's */
/* This defines what an unsigned 16-bit number on the system is */


typedef UWORD_16  barsize_t;             /* 8-bit number */
#define BS_MAX   UBYTE_MAX              /* limit of count for bar_size */

typedef barsize_t *bar_array_t; /* array of bar_sizings */
/* bar array is defined such that the 0-th (bar_size[0]) bar is black   */

/* Intefaces follow:  */
int clean_bars (bar_array_t bar, int count);    /* returns # of bars, -1 on err */
int analyze_c39 (bar_array_t bar, int count, char *targstr);
int analyze_i25 (bar_array_t bar, int count, char *targstr);
